<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="pt_PT" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="54"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Open unknown files in plain text mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Markdown extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Color scheme file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="54"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="21"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="28"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="32"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="37"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="1121"/>
        <source>New document</source>
        <translation>Novo documento</translation>
    </message>
    <message>
        <location filename="window.py" line="61"/>
        <source>File toolbar</source>
        <translation>Barra de Ferramentas de Ficheiros</translation>
    </message>
    <message>
        <location filename="window.py" line="63"/>
        <source>Edit toolbar</source>
        <translation>Editar barra de ferramentas</translation>
    </message>
    <message>
        <location filename="window.py" line="69"/>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <location filename="window.py" line="72"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="window.py" line="80"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="window.py" line="84"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="window.py" line="90"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>Print preview</source>
        <translation>Pré-visualizar impressão</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>View HTML code</source>
        <translation>Ver código HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Change default font</source>
        <translation>Mudar tipo de letra padrão</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Preview</source>
        <translation>Pré-visualizar</translation>
    </message>
    <message>
        <location filename="window.py" line="110"/>
        <source>Live preview</source>
        <translation>Pré-visualizar</translation>
    </message>
    <message>
        <location filename="window.py" line="122"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <location filename="window.py" line="127"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="window.py" line="129"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="window.py" line="131"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="window.py" line="133"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Plain text</source>
        <translation>Texto Simples</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Open recent</source>
        <translation>Abrir recentes</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>Generate webpages</source>
        <translation>Gerar páginas web</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>About Qt</source>
        <translation>So o Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="191"/>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <location filename="window.py" line="209"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location filename="window.py" line="210"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="window.py" line="217"/>
        <source>Directory</source>
        <translation>Directoria</translation>
    </message>
    <message>
        <location filename="window.py" line="229"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="window.py" line="739"/>
        <source>Please, save the file somewhere.</source>
        <translation>Guarde o ficheiro noutro lugar por favor.</translation>
    </message>
    <message>
        <location filename="window.py" line="728"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Páginas Web guardadas nas directoria &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="window.py" line="858"/>
        <source>Supported files</source>
        <translation>Ficheiros Suportados</translation>
    </message>
    <message>
        <location filename="window.py" line="858"/>
        <source>All files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="942"/>
        <source>Plain text (*.txt)</source>
        <translation>Texto Simples (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1020"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Ficheiros HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1020"/>
        <source>Save file</source>
        <translation>Guardar Ficheiro</translation>
    </message>
    <message>
        <location filename="window.py" line="1010"/>
        <source>Export document to ODT</source>
        <translation>Exportar para ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="1010"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Abrir ficheros OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1042"/>
        <source>Export document to PDF</source>
        <translation>Exportar para PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="1042"/>
        <source>PDF files (*.pdf)</source>
        <translation>Ficheiros PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1059"/>
        <source>Print document</source>
        <translation>Imprimir documento</translation>
    </message>
    <message>
        <location filename="window.py" line="1180"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>O documernto foi alterado
Deseja gravar as alterações?</translation>
    </message>
    <message>
        <location filename="window.py" line="1204"/>
        <source>HTML code</source>
        <translation>Código HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="1080"/>
        <source>Export document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="143"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>Set locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>Spell check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Fullscreen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="65"/>
        <source>Search toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="97"/>
        <source>Find text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="150"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="152"/>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="299"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="301"/>
        <source>Case sensitively</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>Markdown syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>reStructuredText syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1215"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="858"/>
        <source>Select one or several files to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="154"/>
        <source>Get help online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="730"/>
        <source>Show directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="965"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="179"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="183"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="261"/>
        <source>Formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="155"/>
        <source>About %s</source>
        <comment>Example of final string: About ReText</comment>
        <translation>Sobre %s</translation>
    </message>
    <message>
        <location filename="window.py" line="146"/>
        <source>Use WebKit renderer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1099"/>
        <source>Failed to execute the command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="945"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>Ficheiros %s</translation>
    </message>
    <message>
        <location filename="window.py" line="724"/>
        <source>Failed to copy default template, please create template.html manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="641"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="258"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="564"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="75"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="917"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="78"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="86"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="88"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="112"/>
        <source>Table mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
